@@ -9,12 +9,12 @@ import subprocess
 import sys
 import traceback
 
-import pkg_resources
-
 from pyshrimp._internal.scriptrunner.cli import _handle_cli_maybe
 from pyshrimp._internal.utils.platformspecific import running_on_windows
 from pyshrimp.utils.locking import acquire_file_lock
 
+from pyshrimp import __version__ as pyshrimp_version
+
 
 def _running_in_dev_mode():
     import pyshrimp._internal as pyshrimp_internal
@@ -36,11 +36,13 @@ def _default_env_config():
         cache_dir=os.path.abspath(os.environ.get('PYSHRIMP_CACHE_DIR', None) or os.path.expanduser('~/.cache/pyshrimp'))
     )
 
+
 def _iter_file_lines(file_path: str):
     with open(file_path, 'r') as f:
         for line in f:
             yield line
 
+
 def _resolve_path(file_path: str, relative_to: str):
     if os.path.isabs(file_path):
         return file_path
@@ -49,6 +51,8 @@ def _resolve_path(file_path: str, relative_to: str):
         return os.path.expanduser(file_path)
 
     return os.path.normpath(os.path.join(relative_to, file_path))
+
+
 class _ScriptConfig:
 
     def __init__(self):
@@ -115,7 +119,7 @@ class _ScriptRunnerBootstrap:
             file_path=m.group(1).strip(),
             relative_to=script_dir
         )
-        
+
         if must_exists:
             if not os.path.exists(file_path):
                 raise self.exit_error(f'Failed to parse config line - file "{file_path}" does not exists: {line.strip()!r}')
@@ -137,7 +141,7 @@ class _ScriptRunnerBootstrap:
         else:
             config.requirements += [
                 # in dist mode install version from pip, not older than the current one
-                f'pyshrimp>={pkg_resources.get_distribution("pyshrimp").version}'
+                f'pyshrimp>={pyshrimp_version}'
             ]
 
         with open(target_script, 'r') as f:
@@ -156,9 +160,9 @@ class _ScriptRunnerBootstrap:
                 elif line.startswith('# $requires:'):
                     config.requirements += self.parse_list_opts(line, r'# \$requires:(.*)')
 
-                elif line.startswith('# $requirements_file:'):
-                    config.requirements += [l.strip() for l in _iter_file_lines(
-                        self.parse_file_path_opt(target_script, line, '# \$requirements_file:(.*)', must_exists=True)    
+                elif re.match(r'^# \$(requirements_file|requirementsFile|requires_file|requiresFile):.*', line):
+                    config.requirements += [requirementsLine.strip() for requirementsLine in _iter_file_lines(
+                        self.parse_file_path_opt(target_script, line, r'# .*?:(.*)', must_exists=True)
                     )]
 
         return config
@@ -305,14 +309,14 @@ class _ScriptRunnerBootstrap:
             raise self.exit_error(
                 f'Setup failed - could not locate python executable among the candidates: {python_executable_path_candidates}'
             )
-        
+
         return python_executable_path
 
     def setup_virtual_env_using_venv(self, venv_dir):
         import venv
         try:
             self.log(f'Setting up venv using venv')
-            venv.create(venv_dir, system_site_packages=True, with_pip=True, clear=True)
+            venv.create(venv_dir, system_site_packages=False, with_pip=True, clear=True)
         except BaseException:
             raise self.exit_error(f'Failed to setup virtualenv! Check previous messages for details.', exc_info=True)
 
@@ -364,7 +368,6 @@ class _ScriptRunnerBootstrap:
             self.log(f'Executing the script: {exec_args}')
             os.execlp(exec_args[0], *exec_args)
 
-
     def _exec_windows_workaround(self, exec_args):
         self.log(f'Executing the script with subprocess: {exec_args}')
 
@@ -375,7 +378,7 @@ class _ScriptRunnerBootstrap:
 
         proc = subprocess.Popen(exec_args)
         proc.wait()
-        
+
         self.log(f'Process completed, exit code: {proc.returncode}')
 
         raise sys.exit(proc.returncode)
